@@ -16,7 +16,7 @@ uicfg.autoform_section.tag_attribute(('Order', 'budget'), 'main', 'hidden')
 uicfg.autoform_section.tag_attribute(('Order', 'progress_target'), 'main', 'hidden')
 uicfg.autoform_section.tag_attribute(('Order', 'progress_todo'), 'main', 'hidden')
 uicfg.autoform_section.tag_attribute(('Order', 'progress_done'), 'main', 'hidden')
-uicfg.autoform_section.tag_subject_of(('Order', 'split_into', '*'), 'main', 'attributes')
+uicfg.autoform_section.tag_subject_of(('Order', 'split_into', '*'), 'main', 'inlined')
 
 # WorkOrder
 uicfg.autoform_section.tag_attribute(('WorkOrder', 'progress_target'), 'main', 'hidden')
